#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
"""remove pod object

Revision ID: ef08a5e057bd
Revises: e647f5931da8
Create Date: 2016-05-24 13:52:39.782156

"""

# revision identifiers, used by Alembic.
revision = 'ef08a5e057bd'
down_revision = 'e647f5931da8'

from alembic import op  # noqa: E402


def upgrade():
    op.drop_table('pod')
